==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/cd_normalise.h <==
 /*
 * file      : cd_normalise.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __cd_normalise_h__
#define __cd_normalise_h__ 1

void      CdNormalise_set_list_PeakGroup (AUDIO *Audio);
void      CdNormalise_set_list_collectif_remove (void);
gboolean  CdNormalise_list_PeakGroup_is_ready (void);
gboolean  CdNormalise_get_is_list_PeakGroup (void);
GList    *CdNormalise_get_list_PeakGroup (void);
void      CdNormalise_set_normalise_ok (void);
void      CdNormalise_add_PeakGroup (void);

#endif

==> xcfa_3.7.3.orig.tar.gz: xcfa-3.7.3/src/cd_normalise.h <==
 /*
 * file      : cd_normalise.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __cd_normalise_h__
#define __cd_normalise_h__ 1


typedef struct {

	gchar	*PathNameSrc;		// Le fichier a normaliser
	gchar	*PathNameDest;		// Destination du fichier
	AUDIO	*Audio;
	
} VAR_CD_NORMALISE_ELEMENT;

typedef struct {
	
	GList	*ListPeakGroup;		// Pointeur sur AUDIO
	gint	 MaxElements;		// 
	gint	 NumExtract;		// 
	gchar	*TmpRep;		// Le dossier temporaire
	
} VAR_CD_NORMALISE;

extern VAR_CD_NORMALISE VarCdNormalise;


void      CdNormalise_set_list_PeakGroup (AUDIO *Audio);
void      CdNormalise_set_list_collectif_remove (void);
gboolean  CdNormalise_list_PeakGroup_is_ready (void);
gboolean  CdNormalise_get_is_list_PeakGroup (void);
GList    *CdNormalise_get_list_PeakGroup (void);
void      CdNormalise_set_normalise_ok (void);
void      CdNormalise_add_PeakGroup (void);

#endif
